## What's Changed

- chore: bump version to 0.1.1 and format dependencies in pyproject.toml (db4fdde)
- docs: update README to encourage contributions and add a note for users (03db133)
- docs: expand README with getting started guide, available tools, and changelog (266836a)
- fix: enhance URL handling in open_url function (b361a45)

**Full Changelog**: https://github.com/leynier/mcp-sys-bridge/compare/v0.1.0...v0.1.1

